from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Interface_Expansion = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AS1115-BQFT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS1115-BQFT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-24-1EP_4x4mm_P0.5mm_EP2.8x2.8mm_PullBack_ThermalVias'], 'footprint':'Package_DFN_QFN:TQFN-24-1EP_4x4mm_P0.5mm_EP2.8x2.8mm_PullBack_ThermalVias', 'keywords':'led driver i2c', 'description':'', 'datasheet':'https://ams.com/documents/20143/36005/AS1115_DS000206_1-00.pdf/3d3e6d35-b184-1329-adf9-2d769eb2404f', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nAS1115-BQFT\n\nled driver i2c', 'pins':[
            Pin(num='1',name='DIG2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='ISET',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SEGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SEGF',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SEGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEGG',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SEGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEGE',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SEGDP',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DIG3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='SEGD',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IRQ',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DIG0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='DIG1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DIG4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='DIG5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='DIG6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DIG7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='KEYA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='KEYB',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS1115-BSST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS1115-BSST'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'led driver i2c', 'description':'', 'datasheet':'https://ams.com/documents/20143/36005/AS1115_DS000206_1-00.pdf/3d3e6d35-b184-1329-adf9-2d769eb2404f', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nAS1115-BSST\n\nled driver i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DIG7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='KEYA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='KEYB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='ISET',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SEGA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEGF',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEGB',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEGG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIG0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='SEGC',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEGE',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEGDP',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEGD',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='IRQ',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='DIG1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='DIG2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='DIG3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DIG4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DIG5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='DIG6',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AW9523B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AW9523B'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'Port-Expander', 'description':'', 'datasheet':'https://cdn-shop.adafruit.com/product-files/4886/AW9523+English+Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nAW9523B\n\nPort-Expander', 'pins':[
            Pin(num='1',name='P1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC4314xGN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC4314xGN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-20_3.9x8.7mm_P0.635mm', 'keywords':'I2C Multiplexer Buffer Level Shifter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/4314f.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nLTC4314xGN\n\nI2C Multiplexer Buffer Level Shifter', 'pins':[
            Pin(num='3',name='SCLOUT1',func=pin_types.BIDIR),
            Pin(num='1',name='DISCEN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ENABLE3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='ENABLE2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='ENABLE1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCLOUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDAOUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SCLOUT4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDAOUT4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{ACC}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDAOUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDAIN',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLOUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDAOUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ENABLE4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC4314xUDC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC4314xUDC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x4mm_P0.5mm_EP1.65x2.65mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x4mm_P0.5mm_EP1.65x2.65mm', 'keywords':'I2C Multiplexer Buffer Level Shifter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/4314f.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nLTC4314xUDC\n\nI2C Multiplexer Buffer Level Shifter', 'pins':[
            Pin(num='1',name='SCLOUT1',func=pin_types.BIDIR),
            Pin(num='10',name='ENABLE1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCLOUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDAOUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SCLOUT4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SDAOUT4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{ACC}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DISCEN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SDAOUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SDAIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SCLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCLOUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SDAOUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='ENABLE4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ENABLE3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='ENABLE2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC4316xDD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC4316xDD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.65x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.65x2.38mm', 'keywords':'I2C Translator 4kV-ESD Level-Shifter Hot-Swap', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/4316fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nLTC4316xDD\n\nI2C Translator 4kV-ESD Level-Shifter Hot-Swap', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCLIN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='XORH',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XORL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='READY',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SDAIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCLOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC4317', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC4317'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-16-1EP_3x5mm_P0.5mm_EP1.66x4.4mm'], 'footprint':'Package_DFN_QFN:DFN-16-1EP_3x5mm_P0.5mm_EP1.66x4.4mm', 'keywords':'I2C Translator 4kV-ESD Level-Shifter Hot-Swap', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/4317fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nLTC4317\n\nI2C Translator 4kV-ESD Level-Shifter Hot-Swap', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='READY1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='SDAOUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDAIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SDAOUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SCLIN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='ENABLE2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XORH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='XORL2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XORH1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XORL1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='ENABLE1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='READY2',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX31910xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX31910xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm'], 'footprint':'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'keywords':'SPI digital input serializer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max31910.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMAX31910xUI\n\nSPI digital input serializer', 'pins':[
            Pin(num='1',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RIREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='V_{CC24V}',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='RT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='MODESEL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX7325AEG+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX7325AEG+'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:QSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Expander I2C Parallel Port GPIO Maxim', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX7325.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMAX7325AEG+\n\nExpander I2C Parallel Port GPIO Maxim', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O10',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O11',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O12',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O13',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='O14',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='O15',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AD2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23008-xML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23008-xML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP23008-MCP23S08-Data-Sheet-20001919F.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23008-xML\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='GP0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23008-xP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23008-xP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP23008-MCP23S08-Data-Sheet-20001919F.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23008-xP\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23008-xSO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23008-xSO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-18W_7.5x11.6mm_P1.27mm'], 'footprint':'Package_SO:SOIC-18W_7.5x11.6mm_P1.27mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP23008-MCP23S08-Data-Sheet-20001919F.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23008-xSO\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23008-xSS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23008-xSS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP23008-MCP23S08-Data-Sheet-20001919F.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23008-xSS\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23017_ML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23017_ML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23017_ML\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23017_SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23017_SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23017_SO\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23017_SP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23017_SP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23017_SP\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23017_SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23017_SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'I2C parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23017_SS\n\nI2C parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23S17_ML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23S17_ML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'SPI parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23S17_ML\n\nSPI parallel port expander', 'pins':[
            Pin(num='1',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23S17_SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23S17_SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'SPI parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23S17_SO\n\nSPI parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23S17_SP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23S17_SP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'microchip i2c parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23S17_SP\n\nmicrochip i2c parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP23S17_SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP23S17_SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'SPI parallel port expander', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20001952C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMCP23S17_SS\n\nSPI parallel port expander', 'pins':[
            Pin(num='1',name='GPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INTB',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='INTA',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='GPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'P82B96', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P82B96'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'I2C Bus Buffer', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/P82B96.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nP82B96\n\nI2C Bus Buffer', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RXD-SDA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TXD-SDA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TXD-SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='RXD-SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9506BS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9506BS'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.3x4.3mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.3x4.3mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9505_9506.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9506BS\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='IO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='IO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='IO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='IO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO3_6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO3_7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='IO4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO4_2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO4_3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO4_4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='IO4_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO4_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO4_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='49',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='IO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='IO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='IO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='IO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO1_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9516', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9516'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'I2C Hub', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9518.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9516\n\nI2C Hub', 'pins':[
            Pin(num='1',name='SCL0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCL3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='EN3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='EN4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='EN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9536D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9536D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'i2c io port', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9536.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9536D\n\ni2c io port', 'pins':[
            Pin(num='1',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9536DP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9536DP'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'i2c io port', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9536.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9536DP\n\ni2c io port', 'pins':[
            Pin(num='1',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9537', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9537'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'i2c io port', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9537.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9537\n\ni2c io port', 'pins':[
            Pin(num='1',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9544AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9544AD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'i2c multiplexer', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9544A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9544AD\n\ni2c multiplexer', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{INT2}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{INT3}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{INT0}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{INT1}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9544APW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9544APW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'i2c multiplexer', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA9544A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9544APW\n\ni2c multiplexer', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{INT2}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{INT3}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{INT0}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{INT1}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9547BS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9547BS'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9547.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9547BS\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9548ADB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9548ADB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9548ADB\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9548ADW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9548ADW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9548ADW\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9555D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9555D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9555D\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='IO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO0_5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9555DB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9555DB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9555DB\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='IO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO0_5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9555PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9555PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9555PW\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='IO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO0_5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9557BS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9557BS'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-16-1EP_3x3mm_P0.5mm_EP1.5x1.5mm'], 'footprint':'Package_DFN_QFN:HVQFN-16-1EP_3x3mm_P0.5mm_EP1.5x1.5mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9557.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9557BS\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9557D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9557D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SO-16_3.9x9.9mm_P1.27mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9557.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9557D\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IO2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9557PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9557PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9557.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9557PW\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IO2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9847PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9847PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'mux i2c switch', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9847.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9847PW\n\nmux i2c switch', 'pins':[
            Pin(num='1',name='V_{DD1}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='V_{DD2}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCAL6416AHF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCAL6416AHF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCAL6416A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCAL6416AHF\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='P0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='V_{DD(P)}',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='V_{DD(I2C-bus)}',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='V_{SS}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCAL6416APW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCAL6416APW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCAL6416A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCAL6416APW\n\nI2C TWI IO expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD_I2C',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDD_P',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0_5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCAL6534EV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCAL6534EV'}), 'ref_prefix':'U', 'fplist':['Package_BGA:NXP_VFBGA-42_2.6x3mm_Layout6x7_P0.4mm_Ball0.25mm_Pad0.24mm'], 'footprint':'Package_BGA:NXP_VFBGA-42_2.6x3mm_Layout6x7_P0.4mm_Ball0.25mm_Pad0.24mm', 'keywords':'I2C TWI IO expander', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCAL6534.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCAL6534EV\n\nI2C TWI IO expander', 'pins':[
            Pin(num='A1',name='V_{DD(I2C-bus)}',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='V_{DD(P)}',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='B2',name='P0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='P0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P3_7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='P3_6',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='P3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='P2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='P3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='P2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P2_4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8574', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8574'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'I2C Expander', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8574_PCF8574A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8574\n\nI2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8574TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8574TS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'I2C Expander', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8574_PCF8574A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8574TS\n\nI2C Expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8575DBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8575DBR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'I2C Expander', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/pcf8575.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8575DBR\n\nI2C Expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8584', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8584'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'I2C Bus', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8584.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8584\n\nI2C Bus', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{RD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{RST}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{IACK}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{INT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='D2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8591', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8591'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'I2C ADC DAC', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8591.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8591\n\nI2C ADC DAC', 'pins':[
            Pin(num='1',name='AIN0',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OSC',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='EXT',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AIN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AIN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AIN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STMPE1600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STMPE1600'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'IO expander 16 GPIO', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/stmpe1600.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nSTMPE1600\n\nIO expander 16 GPIO', 'pins':[
            Pin(num='1',name='GPIO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GPIO_8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO_9',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO_10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO_11',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO_12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO_13',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO_14',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO_15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9534', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9534'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9534.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9534\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535DBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535DBR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535DBR\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535PWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535PWR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535PWR\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535RGER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535RGER'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535RGER\n\nti parallel port', 'pins':[
            Pin(num='1',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535RTWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535RTWR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535RTWR\n\nti parallel port', 'pins':[
            Pin(num='1',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9544A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9544A'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'I2C Hub', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9544a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9544A\n\nI2C Hub', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{INT2}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{INT0}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{INT1}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9548AMRGER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9548AMRGER'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9548AMRGER\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9548APWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9548APWR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9548APWR\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9554DB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9554DB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_5.3x6.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-16_5.3x6.2mm_P0.65mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9554.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9554DB\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9554DBQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9554DBQ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9554.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9554DBQ\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9554DW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9554DW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9554.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9554DW\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9554PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9554PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'SMBUS I2C Expander', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9554.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9554PW\n\nSMBUS I2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPIC6595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPIC6595'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'shift register 8bit', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpic6595.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTPIC6595\n\nshift register 8bit', 'pins':[
            Pin(num='1',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SRCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DRAIN4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='DRAIN5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='DRAIN6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='DRAIN7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='LGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SER_IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DRAIN0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='DRAIN1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='DRAIN2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='DRAIN3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{G}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XRA1201IG24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XRA1201IG24'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'IO expander i2c', 'description':'', 'datasheet':'https://maxlinear-assets.azureedge.net/web/documents/xra1201.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nXRA1201IG24\n\nIO expander i2c', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XRA1201IL24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XRA1201IL24'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'IO expander i2c', 'description':'', 'datasheet':'https://maxlinear-assets.azureedge.net/web/documents/xra1201.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nXRA1201IL24\n\nIO expander i2c', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX31911xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX31911xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm'], 'footprint':'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'keywords':'SPI digital input serializer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max31911.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMAX31911xUI\n\nSPI digital input serializer', 'pins':[
            Pin(num='1',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RIREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='V_{CC24V}',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='RT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='MODESEL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX31912xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX31912xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm'], 'footprint':'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'keywords':'SPI digital input serializer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max31912.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMAX31912xUI\n\nSPI digital input serializer', 'pins':[
            Pin(num='1',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RIREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='V_{CC24V}',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='RT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='MODESEL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX31913xUI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX31913xUI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm'], 'footprint':'Package_SO:TSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.85x6.7mm', 'keywords':'SPI digital input serializer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max31913.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nMAX31913xUI\n\nSPI digital input serializer', 'pins':[
            Pin(num='1',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RIREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='V_{CC24V}',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='RT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='MODESEL',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9547D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9547D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9547.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9547D\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9547PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9547PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9547.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9547PW\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9548APW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9548APW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9548APW\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SC2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9548ARGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9548ARGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCA9548ARGE\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8574A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8574A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'I2C Expander', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8574_PCF8574A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8574A\n\nI2C Expander', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCF8574ATS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8574ATS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:SSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'I2C Expander', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8574_PCF8574A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nPCF8574ATS\n\nI2C Expander', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535DBT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535DBT'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535DBT\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9535MRGER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9535MRGER'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9535.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9535MRGER\n\nti parallel port', 'pins':[
            Pin(num='1',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9548ARGER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9548ARGER'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Low voltage 8-channel I2C switch with reset', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9548a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9548ARGER\n\nLow voltage 8-channel I2C switch with reset', 'pins':[
            Pin(num='1',name='SD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SC4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SC5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SC6',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SC7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SC0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SC3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9555DBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9555DBR'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9555DBR\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9555DBT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9555DBT'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9555DBT\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9555PWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9555PWR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9555PWR\n\nti parallel port', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P05',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9555RGER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9555RGER'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9555RGER\n\nti parallel port', 'pins':[
            Pin(num='1',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9555RTWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9555RTWR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:WQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'ti parallel port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9555.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nTCA9555RTWR\n\nti parallel port', 'pins':[
            Pin(num='1',name='P00',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P01',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P02',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P03',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P04',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P05',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P06',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P07',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XRA1201PIG24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XRA1201PIG24'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'IO expander i2c', 'description':'', 'datasheet':'https://maxlinear-assets.azureedge.net/web/documents/xra1201.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nXRA1201PIG24\n\nIO expander i2c', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XRA1201PIL24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XRA1201PIL24'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'IO expander i2c', 'description':'', 'datasheet':'https://maxlinear-assets.azureedge.net/web/documents/xra1201.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Expansion.kicad_sym\nXRA1201PIL24\n\nIO expander i2c', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])